//line parser.y:2
package main

import __yyfmt__ "fmt"

//line parser.y:2
import (
	"bytes"
	"fmt"
	"io"
	"os"
)

type node struct {
	name       string
	children   []node
	attributes map[string]string
}

func (n node) String() string {
	buf := new(bytes.Buffer)
	n.print(buf, " ")
	return buf.String()
}

func (n node) print(out io.Writer, indent string) {
	if len(n.attributes) > 0 {
		fmt.Fprintf(out, "\n%v%v %s", indent, n.name, n.attributes)
	} else {
		fmt.Fprintf(out, "\n%v%v", indent, n.name)
	}
	for _, nn := range n.children {
		nn.print(out, indent+"  ")
	}
}

func Node(name string) node {
	return node{name: name, attributes: make(map[string]string)}
}

func (n node) append(nn ...node) node {
	n.children = append(n.children, nn...)
	return n
}

func (n node) attribute(key string, value string) node {
	n.attributes[key] = value
	return n
}

//line parser.y:50
type yySymType struct {
	yys   int
	node  node
	token string
	value string
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EVAL = 57348
const T_REQUIRE = 57349
const T_REQUIRE_ONCE = 57350
const T_LOGICAL_OR = 57351
const T_LOGICAL_XOR = 57352
const T_LOGICAL_AND = 57353
const T_PRINT = 57354
const T_YIELD = 57355
const T_DOUBLE_ARROW = 57356
const T_YIELD_FROM = 57357
const T_PLUS_EQUAL = 57358
const T_MINUS_EQUAL = 57359
const T_MUL_EQUAL = 57360
const T_DIV_EQUAL = 57361
const T_CONCAT_EQUAL = 57362
const T_MOD_EQUAL = 57363
const T_AND_EQUAL = 57364
const T_OR_EQUAL = 57365
const T_XOR_EQUAL = 57366
const T_SL_EQUAL = 57367
const T_SR_EQUAL = 57368
const T_POW_EQUAL = 57369
const T_COALESCE = 57370
const T_BOOLEAN_OR = 57371
const T_BOOLEAN_AND = 57372
const T_IS_EQUAL = 57373
const T_IS_NOT_EQUAL = 57374
const T_IS_IDENTICAL = 57375
const T_IS_NOT_IDENTICAL = 57376
const T_SPACESHIP = 57377
const T_IS_SMALLER_OR_EQUAL = 57378
const T_IS_GREATER_OR_EQUAL = 57379
const T_SL = 57380
const T_SR = 57381
const T_INSTANCEOF = 57382
const T_INC = 57383
const T_DEC = 57384
const T_INT_CAST = 57385
const T_DOUBLE_CAST = 57386
const T_STRING_CAST = 57387
const T_ARRAY_CAST = 57388
const T_OBJECT_CAST = 57389
const T_BOOL_CAST = 57390
const T_UNSET_CAST = 57391
const T_POW = 57392
const T_NEW = 57393
const T_CLONE = 57394
const T_NOELSE = 57395
const T_ELSEIF = 57396
const T_ELSE = 57397
const T_ENDIF = 57398
const T_STATIC = 57399
const T_ABSTRACT = 57400
const T_FINAL = 57401
const T_PRIVATE = 57402
const T_PROTECTED = 57403
const T_PUBLIC = 57404
const T_EXIT = 57405
const T_IF = 57406
const T_LNUMBER = 57407
const T_DNUMBER = 57408
const T_STRING = 57409
const T_STRING_VARNAME = 57410
const T_VARIABLE = 57411
const T_NUM_STRING = 57412
const T_INLINE_HTML = 57413
const T_CHARACTER = 57414
const T_BAD_CHARACTER = 57415
const T_ENCAPSED_AND_WHITESPACE = 57416
const T_CONSTANT_ENCAPSED_STRING = 57417
const T_ECHO = 57418
const T_DO = 57419
const T_WHILE = 57420
const T_ENDWHILE = 57421
const T_FOR = 57422
const T_ENDFOR = 57423
const T_FOREACH = 57424
const T_ENDFOREACH = 57425
const T_DECLARE = 57426
const T_ENDDECLARE = 57427
const T_AS = 57428
const T_SWITCH = 57429
const T_ENDSWITCH = 57430
const T_CASE = 57431
const T_DEFAULT = 57432
const T_BREAK = 57433
const T_CONTINUE = 57434
const T_GOTO = 57435
const T_FUNCTION = 57436
const T_CONST = 57437
const T_RETURN = 57438
const T_TRY = 57439
const T_CATCH = 57440
const T_FINALLY = 57441
const T_THROW = 57442
const T_USE = 57443
const T_INSTEADOF = 57444
const T_GLOBAL = 57445
const T_VAR = 57446
const T_UNSET = 57447
const T_ISSET = 57448
const T_EMPTY = 57449
const T_HALT_COMPILER = 57450
const T_CLASS = 57451
const T_TRAIT = 57452
const T_INTERFACE = 57453
const T_EXTENDS = 57454
const T_IMPLEMENTS = 57455
const T_OBJECT_OPERATOR = 57456
const T_LIST = 57457
const T_ARRAY = 57458
const T_CALLABLE = 57459
const T_CLASS_C = 57460
const T_TRAIT_C = 57461
const T_METHOD_C = 57462
const T_FUNC_C = 57463
const T_LINE = 57464
const T_FILE = 57465
const T_COMMENT = 57466
const T_DOC_COMMENT = 57467
const T_OPEN_TAG = 57468
const T_OPEN_TAG_WITH_ECHO = 57469
const T_CLOSE_TAG = 57470
const T_WHITESPACE = 57471
const T_START_HEREDOC = 57472
const T_END_HEREDOC = 57473
const T_DOLLAR_OPEN_CURLY_BRACES = 57474
const T_CURLY_OPEN = 57475
const T_PAAMAYIM_NEKUDOTAYIM = 57476
const T_NAMESPACE = 57477
const T_NS_C = 57478
const T_DIR = 57479
const T_NS_SEPARATOR = 57480
const T_ELLIPSIS = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"','",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_PRINT",
	"T_YIELD",
	"T_DOUBLE_ARROW",
	"T_YIELD_FROM",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"'?'",
	"':'",
	"T_COALESCE",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"'&'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_SPACESHIP",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'+'",
	"'-'",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"'!'",
	"T_INSTANCEOF",
	"'~'",
	"T_INC",
	"T_DEC",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"'@'",
	"T_POW",
	"'['",
	"T_NEW",
	"T_CLONE",
	"T_NOELSE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"';'",
	"'{'",
	"'}'",
	"'('",
	"')'",
	"']'",
	"'$'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line parser.y:706
const src = `<?php

foreach ($a = $b as $k => list($a, $b => $c,)) :
    echo $b;
endforeach;

`

func main() {
	yyDebug = 0
	yyErrorVerbose = true
	l := newLexer(bytes.NewBufferString(src), os.Stdout, "file.name")
	yyParse(l)
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 84,
	159, 46,
	-2, 269,
	-1, 289,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 241,
	-1, 290,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 242,
	-1, 291,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 243,
	-1, 292,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 244,
	-1, 293,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 245,
	-1, 294,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 246,
	-1, 295,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 247,
	-1, 296,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 248,
	-1, 297,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 249,
	-1, 348,
	163, 179,
	-2, 184,
}

const yyPrivate = 57344

const yyLast = 3513

var yyAct = [...]int{

	23, 408, 435, 455, 381, 410, 387, 66, 379, 372,
	382, 146, 302, 399, 143, 163, 160, 153, 153, 153,
	258, 157, 164, 63, 440, 253, 63, 62, 4, 492,
	482, 463, 462, 453, 415, 370, 481, 222, 374, 148,
	225, 226, 227, 228, 229, 444, 231, 158, 233, 234,
	235, 236, 237, 238, 239, 240, 241, 242, 243, 244,
	245, 407, 348, 31, 335, 310, 308, 232, 230, 221,
	376, 195, 405, 194, 151, 150, 147, 222, 390, 66,
	231, 350, 233, 234, 243, 244, 168, 170, 169, 63,
	430, 431, 247, 430, 431, 246, 368, 383, 271, 469,
	64, 223, 224, 64, 456, 349, 192, 307, 193, 166,
	167, 171, 173, 172, 185, 186, 183, 184, 187, 188,
	189, 190, 191, 181, 182, 175, 176, 174, 177, 179,
	180, 268, 266, 493, 487, 375, 477, 459, 452, 427,
	424, 421, 403, 458, 178, 402, 429, 400, 256, 398,
	66, 260, 261, 145, 336, 145, 311, 264, 263, 262,
	257, 249, 248, 449, 250, 471, 64, 272, 273, 274,
	275, 276, 277, 278, 279, 280, 281, 282, 283, 284,
	285, 286, 287, 288, 289, 290, 291, 292, 293, 294,
	295, 296, 297, 298, 300, 161, 304, 145, 60, 61,
	333, 306, 385, 386, 385, 386, 305, 313, 315, 316,
	317, 318, 319, 320, 321, 322, 323, 324, 325, 326,
	404, 389, 327, 389, 388, 367, 388, 200, 309, 201,
	202, 329, 457, 330, 460, 430, 431, 178, 418, 397,
	433, 430, 431, 203, 205, 204, 197, 332, 270, 198,
	181, 182, 175, 176, 174, 177, 179, 180, 303, 175,
	176, 174, 177, 179, 180, 446, 423, 177, 179, 180,
	341, 178, 164, 312, 33, 484, 269, 152, 178, 441,
	416, 267, 265, 178, 346, 340, 337, 342, 339, 254,
	255, 345, 5, 8, 158, 154, 155, 68, 69, 1,
	344, 411, 199, 409, 301, 162, 159, 156, 366, 351,
	472, 352, 259, 360, 11, 354, 30, 10, 29, 35,
	32, 378, 377, 445, 353, 380, 27, 251, 2, 384,
	144, 3, 358, 65, 196, 448, 363, 260, 365, 417,
	0, 0, 0, 0, 369, 188, 189, 190, 191, 181,
	182, 175, 176, 174, 177, 179, 180, 364, 0, 371,
	361, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	178, 0, 0, 0, 396, 0, 0, 412, 0, 0,
	0, 394, 401, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 419, 420, 0, 0, 0, 260,
	0, 0, 0, 0, 0, 0, 0, 425, 412, 439,
	303, 373, 0, 0, 432, 438, 434, 422, 0, 428,
	0, 0, 0, 0, 0, 447, 0, 0, 450, 0,
	436, 454, 0, 0, 0, 451, 0, 0, 406, 0,
	0, 0, 412, 465, 0, 412, 468, 464, 0, 461,
	0, 470, 0, 0, 0, 0, 0, 0, 475, 0,
	0, 0, 0, 0, 0, 479, 0, 476, 0, 373,
	0, 0, 0, 0, 0, 0, 0, 443, 0, 473,
	0, 483, 412, 488, 0, 490, 485, 486, 436, 78,
	79, 80, 81, 82, 0, 85, 86, 87, 83, 84,
	192, 59, 193, 166, 167, 171, 173, 172, 185, 186,
	183, 184, 187, 188, 189, 190, 191, 181, 182, 175,
	176, 174, 177, 179, 180, 0, 0, 0, 0, 0,
	480, 0, 0, 0, 39, 40, 0, 0, 178, 0,
	41, 88, 42, 37, 38, 49, 50, 51, 52, 53,
	54, 55, 56, 0, 0, 89, 76, 0, 92, 93,
	94, 70, 71, 72, 73, 74, 75, 90, 91, 0,
	0, 67, 0, 63, 0, 0, 0, 0, 0, 0,
	95, 96, 97, 98, 99, 100, 101, 102, 103, 104,
	105, 122, 123, 124, 125, 126, 116, 117, 118, 119,
	120, 106, 107, 108, 109, 110, 111, 112, 113, 114,
	115, 77, 0, 134, 132, 133, 129, 130, 0, 121,
	127, 128, 135, 136, 138, 137, 139, 140, 0, 0,
	0, 0, 0, 149, 45, 46, 47, 48, 0, 131,
	142, 141, 57, 58, 0, 59, 0, 43, 0, 0,
	64, 167, 171, 173, 172, 185, 186, 183, 184, 187,
	188, 189, 190, 191, 181, 182, 175, 176, 174, 177,
	179, 180, 0, 0, 0, 0, 0, 0, 39, 40,
	0, 0, 0, 0, 41, 178, 42, 37, 38, 49,
	50, 51, 52, 53, 54, 55, 56, 0, 0, 0,
	36, 0, 0, 0, 0, 20, 60, 61, 0, 0,
	0, 0, 34, 0, 0, 0, 0, 63, 0, 22,
	0, 0, 0, 0, 21, 13, 12, 0, 14, 491,
	25, 0, 0, 0, 0, 15, 0, 0, 0, 16,
	17, 0, 26, 0, 18, 0, 0, 0, 0, 0,
	0, 19, 0, 24, 0, 44, 0, 28, 149, 45,
	46, 47, 48, 0, 0, 0, 0, 57, 58, 0,
	59, 172, 185, 186, 183, 184, 187, 188, 189, 190,
	191, 181, 182, 175, 176, 174, 177, 179, 180, 9,
	0, 43, 0, 0, 64, 0, 0, 0, 0, 0,
	0, 0, 178, 39, 40, 0, 0, 0, 0, 41,
	0, 42, 37, 38, 49, 50, 51, 52, 53, 54,
	55, 56, 0, 0, 0, 36, 0, 0, 0, 0,
	20, 60, 61, 0, 0, 0, 0, 34, 0, 0,
	0, 0, 63, 0, 22, 0, 0, 0, 0, 21,
	13, 12, 0, 14, 0, 25, 0, 0, 0, 0,
	15, 0, 0, 0, 16, 17, 0, 26, 0, 18,
	0, 0, 0, 0, 0, 0, 19, 0, 24, 0,
	44, 0, 28, 149, 45, 46, 47, 48, 0, 0,
	0, 0, 57, 58, 0, 59, 185, 186, 183, 184,
	187, 188, 189, 190, 191, 181, 182, 175, 176, 174,
	177, 179, 180, 0, 9, 489, 43, 0, 0, 64,
	0, 0, 0, 0, 0, 0, 178, 0, 39, 40,
	0, 0, 0, 0, 41, 0, 42, 37, 38, 49,
	50, 51, 52, 53, 54, 55, 56, 0, 0, 0,
	36, 0, 0, 0, 0, 20, 60, 61, 0, 0,
	0, 0, 34, 0, 0, 0, 0, 63, 0, 22,
	0, 0, 0, 0, 21, 13, 12, 0, 14, 0,
	25, 478, 0, 0, 0, 15, 0, 0, 0, 16,
	17, 0, 26, 0, 18, 0, 0, 0, 0, 0,
	0, 19, 0, 24, 0, 44, 0, 28, 149, 45,
	46, 47, 48, 0, 0, 0, 0, 57, 58, 0,
	59, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 9,
	0, 43, 0, 0, 64, 0, 0, 0, 0, 0,
	0, 0, 0, 39, 40, 0, 0, 0, 0, 41,
	0, 42, 37, 38, 49, 50, 51, 52, 53, 54,
	55, 56, 0, 0, 0, 36, 0, 0, 0, 0,
	20, 60, 61, 0, 0, 0, 0, 34, 0, 0,
	0, 0, 63, 0, 22, 0, 0, 0, 0, 21,
	13, 12, 426, 14, 0, 25, 0, 0, 0, 0,
	15, 0, 0, 0, 16, 17, 0, 26, 0, 18,
	0, 0, 0, 0, 0, 0, 19, 0, 24, 0,
	44, 0, 28, 149, 45, 46, 47, 48, 0, 0,
	0, 0, 57, 58, 0, 59, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 9, 0, 43, 0, 0, 64,
	0, 0, 0, 0, 0, 0, 0, 0, 39, 40,
	0, 0, 0, 0, 41, 0, 42, 37, 38, 49,
	50, 51, 52, 53, 54, 55, 56, 0, 0, 0,
	36, 0, 0, 0, 393, 20, 60, 61, 0, 0,
	0, 0, 34, 0, 0, 0, 0, 63, 0, 22,
	0, 0, 0, 0, 21, 13, 12, 0, 14, 0,
	25, 0, 0, 0, 0, 15, 0, 0, 0, 16,
	17, 0, 26, 0, 18, 0, 0, 0, 0, 0,
	0, 19, 0, 24, 0, 44, 0, 28, 149, 45,
	46, 47, 48, 0, 0, 0, 0, 57, 58, 0,
	59, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 9,
	0, 43, 0, 0, 64, 0, 0, 0, 0, 0,
	0, 0, 0, 39, 40, 0, 0, 0, 0, 41,
	0, 42, 37, 38, 49, 50, 51, 52, 53, 54,
	55, 56, 0, 0, 0, 36, 0, 0, 0, 0,
	20, 60, 61, 0, 0, 0, 0, 34, 0, 0,
	0, 0, 63, 0, 22, 0, 0, 0, 0, 21,
	13, 12, 0, 14, 0, 25, 0, 0, 0, 0,
	15, 0, 0, 0, 16, 17, 0, 26, 0, 18,
	0, 0, 0, 0, 0, 0, 19, 0, 24, 0,
	44, 0, 28, 6, 45, 46, 47, 48, 0, 0,
	0, 0, 57, 58, 0, 59, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 9, 252, 43, 0, 0, 64,
	0, 0, 0, 0, 0, 0, 0, 0, 39, 40,
	0, 0, 0, 0, 41, 0, 42, 37, 38, 49,
	50, 51, 52, 53, 54, 55, 56, 0, 0, 0,
	36, 0, 0, 0, 0, 20, 60, 61, 0, 0,
	0, 0, 34, 0, 0, 0, 0, 63, 0, 22,
	0, 0, 0, 0, 21, 13, 12, 0, 14, 0,
	25, 0, 0, 0, 0, 15, 0, 0, 0, 16,
	17, 0, 26, 0, 18, 0, 0, 0, 0, 0,
	0, 19, 0, 24, 0, 44, 0, 28, 149, 45,
	46, 47, 48, 0, 0, 0, 0, 57, 58, 0,
	59, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 7, 0, 0, 0, 0, 0, 9,
	0, 43, 0, 0, 64, 0, 0, 0, 0, 0,
	0, 0, 0, 39, 40, 0, 0, 0, 0, 41,
	0, 42, 37, 38, 49, 50, 51, 52, 53, 54,
	55, 56, 0, 0, 0, 36, 0, 0, 0, 0,
	20, 60, 61, 0, 0, 0, 0, 34, 0, 0,
	0, 0, 63, 0, 22, 0, 0, 0, 0, 21,
	13, 12, 0, 14, 0, 25, 0, 0, 0, 0,
	15, 0, 0, 0, 16, 17, 0, 26, 0, 18,
	0, 0, 0, 0, 0, 0, 19, 0, 24, 0,
	44, 0, 28, 149, 45, 46, 47, 48, 0, 0,
	0, 0, 57, 58, 0, 59, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	437, 0, 0, 0, 9, 0, 43, 0, 0, 64,
	0, 0, 0, 0, 0, 0, 0, 0, 39, 40,
	0, 0, 0, 0, 41, 0, 42, 37, 38, 49,
	50, 51, 52, 53, 54, 55, 56, 0, 0, 0,
	36, 0, 0, 0, 0, 20, 0, 0, 0, 0,
	0, 0, 34, 0, 0, 0, 0, 63, 0, 22,
	0, 0, 0, 0, 21, 13, 12, 0, 14, 0,
	25, 0, 0, 0, 0, 15, 0, 0, 0, 16,
	17, 0, 0, 0, 18, 0, 0, 0, 0, 0,
	0, 19, 0, 24, 0, 44, 149, 45, 46, 47,
	48, 0, 0, 0, 0, 57, 58, 0, 59, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 474, 0, 0, 0, 0, 0, 9,
	0, 43, 0, 0, 64, 0, 0, 0, 0, 0,
	0, 39, 40, 0, 0, 0, 0, 41, 0, 42,
	37, 38, 49, 50, 51, 52, 53, 54, 55, 56,
	0, 0, 0, 36, 0, 0, 0, 0, 20, 0,
	0, 0, 0, 0, 0, 34, 0, 0, 0, 0,
	63, 0, 22, 0, 0, 0, 0, 21, 13, 12,
	0, 14, 0, 25, 0, 0, 0, 0, 15, 0,
	0, 0, 16, 17, 0, 0, 0, 18, 0, 0,
	0, 0, 0, 0, 19, 0, 24, 0, 44, 149,
	45, 46, 47, 48, 0, 0, 0, 0, 57, 58,
	0, 59, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 395, 0, 0, 0,
	0, 0, 9, 0, 43, 0, 0, 64, 0, 0,
	0, 0, 0, 0, 39, 40, 0, 0, 0, 0,
	41, 0, 42, 37, 38, 49, 50, 51, 52, 53,
	54, 55, 56, 0, 0, 0, 36, 0, 0, 0,
	0, 20, 0, 0, 0, 0, 0, 0, 34, 0,
	0, 0, 0, 63, 0, 22, 0, 0, 0, 0,
	21, 13, 12, 0, 14, 0, 25, 0, 0, 0,
	0, 15, 0, 0, 0, 16, 17, 0, 0, 0,
	18, 0, 0, 0, 0, 0, 0, 19, 0, 24,
	0, 44, 149, 45, 46, 47, 48, 0, 0, 0,
	0, 57, 58, 0, 59, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 362,
	0, 0, 0, 0, 0, 9, 0, 43, 0, 0,
	64, 0, 0, 0, 0, 0, 0, 39, 40, 0,
	0, 0, 0, 41, 0, 42, 37, 38, 49, 50,
	51, 52, 53, 54, 55, 56, 0, 0, 0, 36,
	0, 0, 0, 0, 20, 0, 0, 0, 0, 0,
	0, 34, 0, 0, 0, 0, 63, 0, 22, 0,
	0, 0, 0, 21, 13, 12, 0, 14, 0, 25,
	0, 0, 0, 0, 15, 0, 0, 0, 16, 17,
	0, 0, 0, 18, 0, 0, 0, 0, 0, 0,
	19, 0, 24, 0, 44, 149, 45, 46, 47, 48,
	0, 0, 0, 0, 57, 58, 0, 59, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 9, 0,
	43, 0, 0, 64, 0, 0, 0, 0, 0, 0,
	39, 40, 0, 0, 0, 0, 41, 0, 42, 37,
	38, 49, 50, 51, 52, 53, 54, 55, 56, 0,
	0, 0, 36, 0, 0, 0, 0, 20, 0, 0,
	0, 0, 0, 0, 34, 0, 0, 0, 0, 63,
	0, 22, 0, 0, 0, 0, 21, 13, 12, 0,
	14, 0, 25, 0, 0, 0, 0, 15, 0, 0,
	0, 16, 17, 0, 0, 0, 18, 0, 0, 0,
	0, 0, 0, 19, 0, 24, 0, 44, 0, 149,
	45, 46, 47, 48, 0, 0, 0, 0, 57, 58,
	0, 59, 0, 0, 0, 0, 0, 0, 149, 45,
	46, 47, 48, 0, 0, 0, 0, 57, 58, 0,
	59, 9, 413, 43, 0, 0, 64, 0, 0, 0,
	0, 0, 0, 0, 39, 40, 0, 0, 0, 0,
	41, 466, 42, 37, 38, 49, 50, 51, 52, 53,
	54, 55, 56, 39, 40, 0, 36, 0, 0, 41,
	0, 42, 37, 38, 49, 50, 51, 52, 53, 54,
	55, 56, 0, 63, 0, 36, 206, 207, 208, 209,
	211, 212, 213, 214, 215, 216, 217, 218, 210, 0,
	0, 0, 63, 0, 0, 0, 0, 0, 149, 45,
	46, 47, 48, 0, 0, 0, 0, 57, 58, 0,
	59, 44, 0, 0, 0, 0, 0, 219, 220, 414,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	44, 314, 0, 0, 0, 0, 0, 0, 467, 0,
	0, 0, 0, 39, 40, 0, 0, 43, 0, 41,
	64, 42, 37, 38, 49, 50, 51, 52, 53, 54,
	55, 56, 0, 0, 0, 36, 43, 0, 0, 64,
	0, 149, 45, 46, 47, 48, 0, 0, 0, 0,
	57, 58, 63, 59, 0, 0, 0, 0, 0, 0,
	149, 45, 46, 47, 48, 0, 0, 0, 299, 57,
	58, 0, 59, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 39, 40, 0, 0,
	44, 0, 41, 0, 42, 37, 38, 49, 50, 51,
	52, 53, 54, 55, 56, 39, 40, 0, 36, 0,
	0, 41, 0, 42, 37, 38, 49, 50, 51, 52,
	53, 54, 55, 56, 0, 63, 43, 36, 0, 64,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 63, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 44, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 44, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 43,
	0, 0, 64, 168, 170, 169, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 43, 0,
	0, 64, 0, 192, 0, 193, 166, 167, 171, 173,
	172, 185, 186, 183, 184, 187, 188, 189, 190, 191,
	181, 182, 175, 176, 174, 177, 179, 180, 168, 170,
	169, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 178, 0, 0, 0, 0, 0, 0, 192, 0,
	193, 166, 167, 171, 173, 172, 185, 186, 183, 184,
	187, 188, 189, 190, 191, 181, 182, 175, 176, 174,
	177, 179, 180, 168, 170, 169, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 178, 0, 0, 0,
	0, 0, 0, 192, 0, 193, 166, 167, 171, 173,
	172, 185, 186, 183, 184, 187, 188, 189, 190, 191,
	181, 182, 175, 176, 174, 177, 179, 180, 168, 170,
	169, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 178, 0, 0, 0, 0, 392, 0, 192, 0,
	193, 166, 167, 171, 173, 172, 185, 186, 183, 184,
	187, 188, 189, 190, 191, 181, 182, 175, 176, 174,
	177, 179, 180, 168, 170, 169, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 178, 0, 0, 0,
	0, 391, 0, 192, 0, 193, 166, 167, 171, 173,
	172, 185, 186, 183, 184, 187, 188, 189, 190, 191,
	181, 182, 175, 176, 174, 177, 179, 180, 168, 170,
	169, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 178, 0, 0, 0, 0, 357, 0, 192, 0,
	193, 166, 167, 171, 173, 172, 185, 186, 183, 184,
	187, 188, 189, 190, 191, 181, 182, 175, 176, 174,
	177, 179, 180, 168, 170, 169, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 178, 0, 0, 0,
	0, 356, 0, 192, 0, 193, 166, 167, 171, 173,
	172, 185, 186, 183, 184, 187, 188, 189, 190, 191,
	181, 182, 175, 176, 174, 177, 179, 180, 168, 170,
	169, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 178, 0, 0, 0, 0, 355, 0, 192, 0,
	193, 166, 167, 171, 173, 172, 185, 186, 183, 184,
	187, 188, 189, 190, 191, 181, 182, 175, 176, 174,
	177, 179, 180, 168, 170, 169, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 178, 0, 0, 0,
	0, 338, 0, 192, 0, 193, 166, 167, 171, 173,
	172, 185, 186, 183, 184, 187, 188, 189, 190, 191,
	181, 182, 175, 176, 174, 177, 179, 180, 168, 170,
	169, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 178, 0, 0, 0, 0, 334, 0, 192, 456,
	193, 166, 167, 171, 173, 172, 185, 186, 183, 184,
	187, 188, 189, 190, 191, 181, 182, 175, 176, 174,
	177, 179, 180, 168, 170, 169, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 178, 0, 0, 0,
	0, 328, 0, 192, 0, 193, 166, 167, 171, 173,
	172, 185, 186, 183, 184, 187, 188, 189, 190, 191,
	181, 182, 175, 176, 174, 177, 179, 180, 168, 170,
	169, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 178, 0, 0, 359, 0, 0, 0, 192, 0,
	193, 166, 167, 171, 173, 172, 185, 186, 183, 184,
	187, 188, 189, 190, 191, 181, 182, 175, 176, 174,
	177, 179, 180, 168, 170, 169, 0, 0, 442, 0,
	0, 0, 0, 0, 0, 0, 178, 457, 0, 0,
	0, 0, 0, 192, 0, 193, 166, 167, 171, 173,
	172, 185, 186, 183, 184, 187, 188, 189, 190, 191,
	181, 182, 175, 176, 174, 177, 179, 180, 168, 170,
	169, 0, 0, 347, 0, 0, 0, 0, 0, 0,
	0, 178, 165, 0, 0, 0, 0, 0, 192, 343,
	193, 166, 167, 171, 173, 172, 185, 186, 183, 184,
	187, 188, 189, 190, 191, 181, 182, 175, 176, 174,
	177, 179, 180, 168, 170, 169, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 178, 0, 0, 0,
	0, 0, 0, 192, 0, 193, 166, 167, 171, 173,
	172, 185, 186, 183, 184, 187, 188, 189, 190, 191,
	181, 182, 175, 176, 174, 177, 179, 180, 170, 169,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 178, 0, 0, 0, 0, 0, 192, 0, 193,
	166, 167, 171, 173, 172, 185, 186, 183, 184, 187,
	188, 189, 190, 191, 181, 182, 175, 176, 174, 177,
	179, 180, 169, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 178, 0, 0, 0, 0,
	192, 0, 193, 166, 167, 171, 173, 172, 185, 186,
	183, 184, 187, 188, 189, 190, 191, 181, 182, 175,
	176, 174, 177, 179, 180, 331, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 178, 0,
	192, 0, 193, 166, 167, 171, 173, 172, 185, 186,
	183, 184, 187, 188, 189, 190, 191, 181, 182, 175,
	176, 174, 177, 179, 180, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 178, 193,
	166, 167, 171, 173, 172, 185, 186, 183, 184, 187,
	188, 189, 190, 191, 181, 182, 175, 176, 174, 177,
	179, 180, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 178, 171, 173, 172, 185,
	186, 183, 184, 187, 188, 189, 190, 191, 181, 182,
	175, 176, 174, 177, 179, 180, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 178,
	173, 172, 185, 186, 183, 184, 187, 188, 189, 190,
	191, 181, 182, 175, 176, 174, 177, 179, 180, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 178,
}
var yyPact = [...]int{

	-1000, -1000, 1379, -1000, -1000, -1000, 485, 111, -1000, -1000,
	-1000, -1000, -86, 2121, -87, -88, 2446, 2446, 2446, -62,
	107, 2446, -1000, 3033, -89, -91, 209, 121, 141, 156,
	170, 2319, -1000, -1000, -93, -1000, 2446, -62, -62, 2446,
	2446, 2446, 2446, 2446, -94, 2446, -95, 2446, 2446, 2446,
	2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446,
	-1000, -1000, -1000, -1000, -65, 3, 3213, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, 2446, -94, 2446, 2446,
	-95, 2446, 2446, 2446, 2446, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, 2, 7, -1000, 1254, 2446, 63, 2446,
	2446, 2446, 0, 3213, -1, -2, 123, -1000, -1000, 122,
	-1000, 259, 89, -1000, 3213, -1000, 2446, 2446, 2446, 2446,
	2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446,
	2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446,
	2446, 2446, 2427, 2446, -62, 2446, 120, -1000, 115, -1000,
	-53, -96, 2121, -97, -3, 242, 2354, 2446, 2446, 2446,
	2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446, 2446, -1000,
	-1000, 2446, -1000, -1000, -1000, 169, 169, 169, 169, 2898,
	2446, 3213, 2446, 3213, 3213, 169, 169, 169, 169, 169,
	169, 169, 169, 470, 3340, 470, 2446, -1000, -1000, -1000,
	114, -1000, -1000, -1000, -1000, -1000, 2853, -98, -5, 277,
	3213, 2808, -1000, -1000, -1000, -1000, -62, -1000, 107, 2446,
	-1000, 2446, 617, 3411, 3257, 470, 3300, 3444, 858, 734,
	215, 215, 215, 169, 169, 169, 169, 210, 210, 302,
	302, 302, 302, 302, 203, 203, 203, 203, 3168, 2446,
	3377, 275, -1000, -1000, 3078, -100, -55, -80, 2446, -1000,
	2446, -1000, -1000, 470, 2446, 470, 470, 470, 470, 470,
	470, 470, 470, 470, 470, 470, 470, 2763, -1000, 2718,
	2673, 2446, 2943, -1000, 1998, 2446, 2446, 2446, 65, -1000,
	-1000, 3213, -1000, 2446, 3377, -128, -62, 1, 67, -83,
	-1000, 2628, 2583, 1129, 858, 1875, -1000, -1000, 470, -1000,
	-1000, -1000, -1000, 76, -10, 3213, -1000, -12, -14, 3377,
	-17, -1000, 57, -1000, -62, -101, 2245, -129, 271, -1000,
	201, -1000, -1000, 69, -1000, -1000, -1000, -1000, 111, -16,
	-1000, 2121, 235, -19, -1000, -1000, 1004, -20, 2446, -15,
	-1000, 133, -1000, -1000, 1629, 1, -1000, 2245, -140, 270,
	-1000, -1000, 3123, -62, -117, 234, 67, 5, -1000, -1000,
	-1000, 111, -1000, -1000, -1000, 1504, -21, -1000, -130, -1000,
	2446, 73, -18, -22, 127, -1000, -1000, -1000, -131, -132,
	-1000, 2245, 2264, -1000, 2245, -61, 67, -1000, 77, -1000,
	-1000, 1504, -1000, 1752, 2988, -1000, -1000, -1000, -1000, -1000,
	-23, 879, 1629, -1000, -1000, 3213, -62, -126, -133, -1000,
	-1000, 258, -1000, -1000, -1000, -1000, 1504, -1000, -25, -1000,
	-1000, 2245, -1000, 754, 2446, 629, 1504, -1000, -134, -1000,
	3213, -26, -1000, -1000,
}
var yyPgo = [...]int{

	0, 274, 339, 335, 334, 333, 331, 6, 330, 329,
	328, 25, 327, 11, 326, 290, 289, 325, 323, 4,
	10, 322, 321, 8, 0, 320, 319, 63, 27, 318,
	317, 316, 314, 313, 20, 312, 310, 308, 13, 277,
	307, 21, 306, 16, 305, 15, 304, 12, 9, 1,
	5, 303, 301, 2, 299, 298, 297, 291, 3,
}
var yyR1 = [...]int{

	0, 54, 55, 55, 55, 55, 55, 55, 55, 55,
	55, 55, 55, 55, 55, 55, 55, 55, 55, 55,
	55, 55, 55, 55, 55, 55, 55, 55, 55, 55,
	55, 55, 55, 55, 55, 55, 55, 55, 55, 55,
	55, 55, 55, 55, 55, 55, 55, 55, 55, 55,
	55, 55, 55, 55, 55, 55, 55, 55, 55, 55,
	55, 55, 55, 55, 55, 55, 55, 55, 55, 56,
	56, 56, 56, 56, 56, 56, 5, 5, 8, 8,
	7, 9, 9, 9, 10, 10, 6, 6, 6, 6,
	6, 13, 13, 12, 12, 12, 11, 11, 11, 11,
	11, 11, 11, 11, 11, 11, 11, 11, 11, 11,
	11, 11, 11, 11, 29, 29, 30, 30, 31, 31,
	32, 32, 33, 33, 34, 34, 35, 35, 37, 37,
	37, 37, 38, 38, 38, 58, 58, 36, 36, 48,
	48, 48, 48, 49, 50, 50, 51, 51, 52, 52,
	52, 52, 52, 52, 53, 53, 40, 40, 41, 42,
	42, 43, 43, 44, 44, 45, 46, 46, 47, 57,
	57, 15, 15, 14, 14, 1, 1, 16, 21, 21,
	22, 22, 23, 23, 17, 17, 4, 4, 2, 2,
	3, 3, 19, 19, 20, 20, 20, 18, 18, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 24, 24, 39, 39, 26, 27, 28,
	28, 28,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 3,
	1, 1, 2, 3, 2, 0, 1, 1, 3, 3,
	1, 2, 0, 1, 1, 1, 3, 1, 1, 5,
	7, 9, 5, 3, 3, 3, 3, 3, 3, 1,
	2, 6, 7, 9, 5, 6, 1, 3, 6, 7,
	3, 6, 1, 4, 0, 1, 3, 1, 3, 4,
	4, 5, 0, 5, 4, 1, 1, 1, 4, 1,
	2, 4, 3, 1, 0, 1, 3, 1, 3, 1,
	4, 2, 6, 4, 1, 4, 3, 1, 1, 3,
	1, 1, 3, 3, 1, 1, 1, 3, 1, 0,
	1, 5, 4, 1, 2, 1, 1, 10, 1, 0,
	1, 3, 4, 6, 0, 1, 0, 1, 0, 1,
	0, 1, 1, 2, 1, 1, 1, 0, 2, 3,
	4, 4, 2, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 2, 2, 2, 2,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 2, 2, 2,
	2, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 5, 4, 3, 4, 2, 2, 4, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 1,
	2, 4, 2, 1, 1, 0, 1, 1, 1, 1,
	4, 2,
}
var yyChk = [...]int{

	-1000, -54, -10, -6, -11, -16, 4, 154, -15, 160,
	-30, -32, 97, 96, 99, 106, 110, 111, 115, 122,
	76, 95, 90, -24, 124, 101, 113, -14, 128, -29,
	-31, -27, -25, -1, 83, -26, 71, 58, 59, 49,
	50, 55, 57, 162, 126, 5, 6, 7, 8, 60,
	61, 62, 63, 64, 65, 66, 67, 13, 14, 16,
	77, 78, -28, 88, 165, -5, -24, 86, -56, -55,
	76, 77, 78, 79, 80, 81, 71, 126, 4, 5,
	6, 7, 8, 13, 14, 10, 11, 12, 56, 70,
	82, 83, 73, 74, 75, 95, 96, 97, 98, 99,
	100, 101, 102, 103, 104, 105, 116, 117, 118, 119,
	120, 121, 122, 123, 124, 125, 111, 112, 113, 114,
	115, 134, 106, 107, 108, 109, 110, 135, 136, 131,
	132, 154, 129, 130, 128, 137, 138, 140, 139, 141,
	142, 156, 155, -7, -8, 86, -13, 162, -11, 4,
	162, 162, -39, -24, -39, -39, -40, -41, -28, -42,
	-43, 88, -44, -45, -24, 159, 33, 34, 10, 12,
	11, 35, 37, 36, 51, 49, 50, 52, 68, 53,
	54, 47, 48, 40, 41, 38, 39, 42, 43, 44,
	45, 46, 30, 32, 162, 162, -4, 37, 128, -1,
	86, 73, 74, 73, 75, 74, 17, 18, 19, 20,
	29, 21, 22, 23, 24, 25, 26, 27, 28, 58,
	59, 162, -24, -27, -27, -24, -24, -24, -24, -24,
	162, -24, 162, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, 160, -28, 159, 159,
	157, -12, 161, -11, -16, -15, -24, 97, -34, -35,
	-24, -24, 159, 159, 159, 159, 9, 159, 9, 17,
	159, 9, -24, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, -24, -24, 31,
	-24, -46, -47, -27, -24, 86, 86, 160, 162, -11,
	162, 159, 31, -24, 37, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, -24, 163, -24,
	-24, 15, -24, 86, 163, 162, 159, 9, 163, -41,
	-43, -24, -45, 31, -24, -57, 9, 105, 162, 160,
	161, -24, -24, -13, -24, 163, 163, 163, -24, 161,
	-33, -11, 31, -24, -34, -24, -37, 160, 31, -24,
	163, -47, -48, -27, 37, 134, 69, -21, -22, -23,
	-17, -19, -20, 30, -9, 135, 136, -7, 157, 154,
	161, 163, 163, 75, -11, 31, -13, 163, 159, -38,
	159, -38, 159, 159, 163, 15, -27, 162, -49, -51,
	-50, -52, -24, 37, 134, 163, 9, -2, 37, -20,
	-7, 157, -11, 31, 159, -13, 98, 159, -34, 161,
	108, 109, -38, 107, -38, -53, -11, 31, -48, -49,
	164, 9, 15, -27, 162, -18, 31, -23, -3, 158,
	-7, -13, 159, 163, -24, -58, 31, 159, 161, 159,
	107, -13, 163, 163, -50, -24, 37, 134, -49, 160,
	-19, 88, -36, -11, 31, -58, -13, 159, 102, -53,
	-27, 162, 163, -13, 17, -13, -13, 159, -49, 161,
	-24, 100, 163, 159,
}
var yyDef = [...]int{

	85, -2, 1, 84, 86, 87, 0, 0, 90, 92,
	97, 98, 0, 0, 0, 0, 275, 275, 275, 0,
	0, 0, 109, 0, 0, 0, 186, 0, 0, 116,
	0, 273, 274, 173, 0, 278, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 269, 0,
	175, 176, 277, 279, 0, 0, 255, 76, 77, 69,
	70, 71, 72, 73, 74, 75, 12, 39, 2, 3,
	4, 5, 6, 45, -2, 7, 8, 9, 10, 11,
	13, 14, 15, 16, 17, 18, 19, 20, 21, 22,
	23, 24, 25, 26, 27, 28, 29, 30, 31, 32,
	33, 34, 35, 36, 37, 38, 40, 41, 42, 43,
	44, 47, 48, 49, 50, 51, 52, 53, 54, 55,
	56, 57, 58, 59, 60, 61, 62, 63, 64, 65,
	66, 67, 68, 0, 80, 78, 0, 0, 0, 0,
	124, 0, 0, 276, 0, 0, 0, 157, 158, 0,
	160, 161, 0, 164, 165, 110, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 187, 0, 174,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 216,
	218, 0, 202, 217, 219, 237, 238, 239, 240, 0,
	0, 256, 0, 258, 259, 260, 261, 262, 263, 264,
	265, 266, 267, 268, 270, 272, 0, 281, 88, 89,
	0, 91, 96, 93, 94, 95, 0, 0, 0, 125,
	127, 0, 103, 104, 105, 106, 0, 107, 0, 0,
	108, 0, 220, 221, 222, 223, 224, 225, 226, 227,
	228, 229, 230, 231, 232, 233, 234, 235, 236, -2,
	-2, -2, -2, -2, -2, -2, -2, -2, 0, 0,
	253, 169, 166, 168, 0, 0, 0, 0, 0, 117,
	0, 120, 92, 199, 0, 203, 204, 205, 206, 207,
	208, 209, 210, 212, 213, 214, 215, 0, 250, 0,
	0, 0, 0, 79, 0, 0, 124, 0, 0, 156,
	159, 162, 163, 0, 252, 0, 170, 0, -2, 0,
	172, 0, 0, 0, 200, 0, 254, 257, 271, 280,
	99, 122, 92, 0, 0, 126, 102, 132, 132, 251,
	0, 167, 0, 139, 0, 0, 144, 0, 178, 180,
	188, 185, 192, 0, 194, 195, 196, 81, 0, 0,
	171, 0, 0, 0, 114, 92, 0, 0, 124, 0,
	132, 0, 132, 111, 0, 0, 140, 144, 0, 143,
	147, 145, 149, 0, 0, 197, 184, 190, 189, 193,
	82, 0, 115, 92, 121, 118, 0, 100, 0, 128,
	0, 0, 0, 0, 0, 112, 154, 92, 0, 0,
	142, 144, 0, 151, 144, 0, 0, 181, 0, 191,
	83, 119, 123, 0, 0, 92, 135, 136, 129, 130,
	0, 0, 0, 141, 146, 148, 0, 0, 0, 92,
	198, 182, 101, 137, 92, 92, 134, 131, 0, 113,
	150, 144, 153, 0, 0, 0, 133, 155, 0, 177,
	183, 0, 152, 138,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 55, 3, 3, 165, 54, 37, 3,
	162, 163, 52, 49, 9, 50, 51, 53, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 31, 159,
	43, 17, 45, 30, 67, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 69, 3, 164, 36, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 160, 35, 161, 57,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 10, 11, 12,
	13, 14, 15, 16, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 32, 33, 34, 38,
	39, 40, 41, 42, 44, 46, 47, 48, 56, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 68, 70,
	71, 72, 73, 74, 75, 76, 77, 78, 79, 80,
	81, 82, 83, 84, 85, 86, 87, 88, 89, 90,
	91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
	111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128, 129, 130,
	131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
	141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
	151, 152, 153, 154, 155, 156, 157, 158,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:232
		{
			fmt.Println(yyDollar[1].node)
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:251
		{
			yyVAL.node = Node("identifier")
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:252
		{
			yyVAL.node = Node("reserved")
		}
	case 78:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:256
		{
			yyVAL.node = Node("NamespaceParts").append(Node(yyDollar[1].token))
		}
	case 79:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:257
		{
			yyVAL.node = yyDollar[1].node.append(Node(yyDollar[3].token))
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:261
		{
			yyVAL.node = yyDollar[1].node
		}
	case 81:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:265
		{
			yyVAL.node = Node("Name").append(yyDollar[1].node)
		}
	case 82:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:266
		{
			yyVAL.node = Node("Name").append(yyDollar[2].node).attribute("FullyQualified", "true")
		}
	case 83:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:267
		{
			yyVAL.node = Node("Name").append(yyDollar[3].node).attribute("Relative", "true")
		}
	case 84:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:271
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 85:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:272
		{
			yyVAL.node = Node("Statements")
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:276
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:277
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:278
		{
			yyVAL.node = yyDollar[2].node /*TODO: identifier stub, refactor it*/
		}
	case 89:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:279
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node)
		}
	case 90:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:280
		{
			yyVAL.node = yyDollar[1].node
		}
	case 91:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:284
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 92:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:285
		{
			yyVAL.node = Node("stmt")
		}
	case 93:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:289
		{
			yyVAL.node = yyDollar[1].node
		}
	case 94:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:290
		{
			yyVAL.node = yyDollar[1].node
		}
	case 95:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:291
		{
			yyVAL.node = yyDollar[1].node
		}
	case 96:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:294
		{
			yyVAL.node = yyDollar[2].node
		}
	case 97:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:295
		{
			yyVAL.node = yyDollar[1].node
		}
	case 98:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:296
		{
			yyVAL.node = yyDollar[1].node
		}
	case 99:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:298
		{
			yyVAL.node = Node("While").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("stmt").append(yyDollar[5].node))
		}
	case 100:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:304
		{
			yyVAL.node = Node("DoWhile").
				append(Node("expr").append(yyDollar[5].node)).
				append(Node("stmt").append(yyDollar[2].node))
		}
	case 101:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:310
		{
			yyVAL.node = Node("For").
				append(Node("expr1").append(yyDollar[3].node)).
				append(Node("expr2").append(yyDollar[5].node)).
				append(Node("expr3").append(yyDollar[7].node)).
				append(Node("stmt").append(yyDollar[9].node))
		}
	case 102:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:317
		{
			yyVAL.node = Node("Switch").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node)
		}
	case 103:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:318
		{
			yyVAL.node = Node("Break").append(yyDollar[2].node)
		}
	case 104:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:319
		{
			yyVAL.node = Node("Continue").append(yyDollar[2].node)
		}
	case 105:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:320
		{
			yyVAL.node = Node("Return").append(yyDollar[2].node)
		}
	case 106:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:321
		{
			yyVAL.node = yyDollar[2].node
		}
	case 107:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:322
		{
			yyVAL.node = yyDollar[2].node
		}
	case 108:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:323
		{
			yyVAL.node = yyDollar[2].node
		}
	case 109:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.node = Node("Echo").append(Node("InlineHtml").attribute("value", yyDollar[1].token))
		}
	case 110:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:325
		{
			yyVAL.node = yyDollar[1].node
		}
	case 111:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:327
		{
			yyVAL.node = Node("Unset").append(yyDollar[3].node)
		}
	case 112:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:329
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachVariable").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 113:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:336
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachKey").append(yyDollar[5].node)).
				append(Node("ForeachVariable").append(yyDollar[7].node)).
				append(yyDollar[9].node)
		}
	case 114:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:346
		{
			yyVAL.node = Node("If").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[5].node))
		}
	case 115:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:350
		{
			yyVAL.node = yyDollar[1].node.append(Node("ElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[6].node)))
		}
	case 116:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:356
		{
			yyVAL.node = yyDollar[1].node
		}
	case 117:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:358
		{
			yyVAL.node = yyDollar[1].node.append(Node("Else").append(Node("stmt").append(yyDollar[3].node)))
		}
	case 118:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:365
		{
			yyVAL.node = Node("AltIf").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[6].node))
		}
	case 119:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:369
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[7].node)))
		}
	case 120:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:375
		{
			yyVAL.node = yyDollar[1].node
		}
	case 121:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:377
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElse").append(Node("stmt").append(yyDollar[4].node)))
		}
	case 122:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:383
		{
			yyVAL.node = yyDollar[1].node
		}
	case 123:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:384
		{
			yyVAL.node = yyDollar[2].node
		}
	case 124:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:388
		{
			yyVAL.node = Node("null")
		}
	case 125:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:389
		{
			yyVAL.node = yyDollar[1].node
		}
	case 126:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:392
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 127:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:393
		{
			yyVAL.node = Node("ExpressionList").append(yyDollar[1].node)
		}
	case 128:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:397
		{
			yyVAL.node = yyDollar[2].node
		}
	case 129:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:398
		{
			yyVAL.node = yyDollar[3].node
		}
	case 130:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:399
		{
			yyVAL.node = yyDollar[2].node
		}
	case 131:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:400
		{
			yyVAL.node = yyDollar[3].node
		}
	case 132:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:404
		{
			yyVAL.node = Node("CaseList")
		}
	case 133:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:406
		{
			yyVAL.node = yyDollar[1].node.append(Node("Case").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node))
		}
	case 134:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:410
		{
			yyVAL.node = yyDollar[1].node.append(Node("Default").append(yyDollar[4].node))
		}
	case 137:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:421
		{
			yyVAL.node = yyDollar[1].node
		}
	case 138:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:422
		{
			yyVAL.node = yyDollar[2].node
		}
	case 139:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:426
		{
			yyVAL.node = yyDollar[1].node
		}
	case 140:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:427
		{
			yyVAL.node = Node("Ref").append(yyDollar[2].node)
		}
	case 141:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:428
		{
			yyVAL.node = Node("List").append(yyDollar[3].node)
		}
	case 142:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:429
		{
			yyVAL.node = Node("ShortList").append(yyDollar[2].node)
		}
	case 143:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:433
		{ /* TODO: allow single trailing comma */
			yyVAL.node = yyDollar[1].node
		}
	case 144:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:437
		{
			yyVAL.node = Node("Null")
		}
	case 145:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:438
		{
			yyVAL.node = yyDollar[1].node
		}
	case 146:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:443
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 147:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:444
		{
			yyVAL.node = Node("ArrayPairList").append(yyDollar[1].node)
		}
	case 148:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:448
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 149:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:449
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node)
		}
	case 150:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:450
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(Node("Ref").append(yyDollar[4].node))
		}
	case 151:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:451
		{
			yyVAL.node = Node("ArrayElement").append(Node("Ref").append(yyDollar[2].node))
		}
	case 152:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:453
		{
			yyVAL.node = Node("ArrayElement").
				append(yyDollar[1].node).
				append(Node("ArrayList").append(yyDollar[5].node))
		}
	case 153:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:459
		{
			yyVAL.node = Node("ArrayElement").
				append(Node("ArrayList").append(yyDollar[3].node))
		}
	case 154:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:466
		{
			yyVAL.node = yyDollar[1].node
		}
	case 155:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:467
		{
			yyVAL.node = yyDollar[2].node
		}
	case 156:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:471
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 157:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:472
		{
			yyVAL.node = Node("GlobalVarList").append(yyDollar[1].node)
		}
	case 158:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:476
		{
			yyVAL.node = yyDollar[1].node
		}
	case 159:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:480
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 160:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:481
		{
			yyVAL.node = Node("StaticVarList").append(yyDollar[1].node)
		}
	case 161:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:485
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token)
		}
	case 162:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:486
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token).append(Node("expr").append(yyDollar[3].node))
		}
	case 163:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:490
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 164:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:491
		{
			yyVAL.node = Node("EchoList").append(yyDollar[1].node)
		}
	case 165:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:495
		{
			yyVAL.node = Node("Echo").append(yyDollar[1].node)
		}
	case 166:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:499
		{
			yyVAL.node = Node("UnsetVariablesList").append(yyDollar[1].node)
		}
	case 167:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:500
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 168:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:504
		{
			yyVAL.node = yyDollar[1].node
		}
	case 171:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:513
		{
			yyVAL.node = yyDollar[1].node.attribute("name", yyDollar[3].token)
		}
	case 172:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:514
		{
			yyVAL.node = Node("Class").attribute("name", yyDollar[2].token)
		}
	case 173:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:517
		{
			yyVAL.node = Node("Class").attribute(yyDollar[1].value, "true")
		}
	case 174:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:518
		{
			yyVAL.node = yyDollar[1].node.attribute(yyDollar[2].value, "true")
		}
	case 175:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:522
		{
			yyVAL.value = "abstract"
		}
	case 176:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:523
		{
			yyVAL.value = "final"
		}
	case 177:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser.y:528
		{
			yyVAL.node = Node("Function").
				attribute("name", yyDollar[3].token).
				attribute("returns_ref", yyDollar[2].value).
				append(yyDollar[5].node).
				append(yyDollar[7].node).
				append(yyDollar[9].node)
		}
	case 178:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:539
		{
			yyVAL.node = yyDollar[1].node
		}
	case 179:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:540
		{
			yyVAL.node = Node("Parameter list")
		}
	case 180:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:543
		{
			yyVAL.node = Node("Parameter list").append(yyDollar[1].node)
		}
	case 181:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:544
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 182:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:548
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token)
		}
	case 183:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:556
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token).
				append(yyDollar[6].node)
		}
	case 184:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:567
		{
			yyVAL.node = Node("No type")
		}
	case 185:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:568
		{
			yyVAL.node = yyDollar[1].node
		}
	case 186:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:572
		{
			yyVAL.value = "false"
		}
	case 187:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:573
		{
			yyVAL.value = "true"
		}
	case 188:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:577
		{
			yyVAL.value = "false"
		}
	case 189:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:578
		{
			yyVAL.value = "true"
		}
	case 190:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:582
		{
			yyVAL.value = "false"
		}
	case 191:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:583
		{
			yyVAL.value = "true"
		}
	case 192:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:587
		{
			yyVAL.node = yyDollar[1].node
		}
	case 193:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:588
		{
			yyVAL.node = yyDollar[2].node
			yyVAL.node.attribute("nullable", "true")
		}
	case 194:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:592
		{
			yyVAL.node = yyDollar[1].node
		}
	case 195:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:593
		{
			yyVAL.node = Node("array type")
		}
	case 196:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:594
		{
			yyVAL.node = Node("callable type")
		}
	case 197:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:598
		{
			yyVAL.node = Node("void")
		}
	case 198:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:599
		{
			yyVAL.node = yyDollar[2].node
		}
	case 199:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:603
		{
			yyVAL.node = Node("Assign").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 200:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:604
		{
			yyVAL.node = Node("AssignRef").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 201:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:605
		{
			yyVAL.node = Node("AssignRef").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 202:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:606
		{
			yyVAL.node = Node("Clone").append(yyDollar[2].node)
		}
	case 203:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:607
		{
			yyVAL.node = Node("AssignAdd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 204:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:608
		{
			yyVAL.node = Node("AssignSub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 205:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:609
		{
			yyVAL.node = Node("AssignMul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 206:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:610
		{
			yyVAL.node = Node("AssignPow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 207:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:611
		{
			yyVAL.node = Node("AssignDiv").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 208:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:612
		{
			yyVAL.node = Node("AssignConcat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 209:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:613
		{
			yyVAL.node = Node("AssignMod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 210:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:614
		{
			yyVAL.node = Node("AssignAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 211:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:615
		{
			yyVAL.node = Node("AssignAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 212:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:616
		{
			yyVAL.node = Node("AssignOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 213:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:617
		{
			yyVAL.node = Node("AssignXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 214:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:618
		{
			yyVAL.node = Node("AssignShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 215:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:619
		{
			yyVAL.node = Node("AssignShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 216:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:620
		{
			yyVAL.node = Node("PostIncrement").append(yyDollar[1].node)
		}
	case 217:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:621
		{
			yyVAL.node = Node("PreIncrement").append(yyDollar[2].node)
		}
	case 218:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:622
		{
			yyVAL.node = Node("PostDecrement").append(yyDollar[1].node)
		}
	case 219:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:623
		{
			yyVAL.node = Node("PreDecrement").append(yyDollar[2].node)
		}
	case 220:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:624
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 221:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:625
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 222:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:626
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 223:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:627
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 224:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:628
		{
			yyVAL.node = Node("Xor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 225:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:629
		{
			yyVAL.node = Node("BitwiseOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 226:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:630
		{
			yyVAL.node = Node("BitwiseAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 227:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:631
		{
			yyVAL.node = Node("BitwiseXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 228:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:632
		{
			yyVAL.node = Node("Concat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 229:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:633
		{
			yyVAL.node = Node("Add").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 230:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:634
		{
			yyVAL.node = Node("Sub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 231:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:635
		{
			yyVAL.node = Node("Mul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 232:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:636
		{
			yyVAL.node = Node("Pow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 233:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:637
		{
			yyVAL.node = Node("Div").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 234:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:638
		{
			yyVAL.node = Node("Mod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 235:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:639
		{
			yyVAL.node = Node("ShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 236:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:640
		{
			yyVAL.node = Node("ShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 237:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:641
		{
			yyVAL.node = Node("UnaryPlus").append(yyDollar[2].node)
		}
	case 238:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:642
		{
			yyVAL.node = Node("UnaryMinus").append(yyDollar[2].node)
		}
	case 239:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:643
		{
			yyVAL.node = Node("BooleanNot").append(yyDollar[2].node)
		}
	case 240:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:644
		{
			yyVAL.node = Node("BitwiseNot").append(yyDollar[2].node)
		}
	case 241:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:645
		{
			yyVAL.node = Node("Identical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 242:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:646
		{
			yyVAL.node = Node("NotIdentical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 243:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:647
		{
			yyVAL.node = Node("Equal").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 244:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:648
		{
			yyVAL.node = Node("NotEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 245:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:649
		{
			yyVAL.node = Node("Spaceship").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:650
		{
			yyVAL.node = Node("Smaller").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 247:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:651
		{
			yyVAL.node = Node("SmallerOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 248:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:652
		{
			yyVAL.node = Node("Greater").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 249:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:653
		{
			yyVAL.node = Node("GreaterOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 250:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:654
		{
			yyVAL.node = yyDollar[2].node
		}
	case 251:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:655
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 252:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:656
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 253:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:657
		{
			yyVAL.node = Node("Coalesce").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 254:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:658
		{
			yyVAL.node = Node("Empty").append(yyDollar[3].node)
		}
	case 255:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:659
		{
			yyVAL.node = Node("Include").append(yyDollar[2].node)
		}
	case 256:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:660
		{
			yyVAL.node = Node("IncludeOnce").append(yyDollar[2].node)
		}
	case 257:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:661
		{
			yyVAL.node = Node("Eval").append(yyDollar[3].node)
		}
	case 258:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:662
		{
			yyVAL.node = Node("Require").append(yyDollar[2].node)
		}
	case 259:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:663
		{
			yyVAL.node = Node("RequireOnce").append(yyDollar[2].node)
		}
	case 260:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:664
		{
			yyVAL.node = Node("CastInt").append(yyDollar[2].node)
		}
	case 261:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:665
		{
			yyVAL.node = Node("CastDouble").append(yyDollar[2].node)
		}
	case 262:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:666
		{
			yyVAL.node = Node("CastString").append(yyDollar[2].node)
		}
	case 263:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:667
		{
			yyVAL.node = Node("CastArray").append(yyDollar[2].node)
		}
	case 264:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:668
		{
			yyVAL.node = Node("CastObject").append(yyDollar[2].node)
		}
	case 265:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:669
		{
			yyVAL.node = Node("CastBool").append(yyDollar[2].node)
		}
	case 266:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:670
		{
			yyVAL.node = Node("CastUnset").append(yyDollar[2].node)
		}
	case 267:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:671
		{
			yyVAL.node = Node("Silence").append(yyDollar[2].node)
		}
	case 268:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:673
		{
			yyVAL.node = Node("Print").append(yyDollar[2].node)
		}
	case 269:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:674
		{
			yyVAL.node = Node("Yield")
		}
	case 270:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:675
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node)
		}
	case 271:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:676
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 272:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:677
		{
			yyVAL.node = Node("YieldFrom").append(yyDollar[2].node)
		}
	case 273:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:681
		{
			yyVAL.node = yyDollar[1].node
		}
	case 274:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:682
		{
			yyVAL.node = yyDollar[1].node
		}
	case 275:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:686
		{
			yyVAL.node = Node("null")
		}
	case 276:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:687
		{
			yyVAL.node = yyDollar[1].node
		}
	case 277:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:691
		{
			yyVAL.node = yyDollar[1].node
		}
	case 278:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:695
		{
			yyVAL.node = yyDollar[1].node
		}
	case 279:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:699
		{
			yyVAL.node = Node("Variable").attribute("name", yyDollar[1].token)
		}
	case 280:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:700
		{
			yyVAL.node = yyDollar[3].node
		}
	case 281:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:701
		{
			yyVAL.node = Node("Variable").append(yyDollar[2].node)
		}
	}
	goto yystack /* stack new state and value */
}
